@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: keys
 version: 3.11
-id: keys-3.11-c0312e613ec912c390e00fde3001f005
-key: keys_FT0yMgPq2OK0SRzfYlHeEH
+id: keys-3.11-ade7d136d0c3ee7dfe52cac8116b48e8
+key: keys_H6H2ELFfMMo4X0tqBHPkuO
 license: BSD3
 copyright: Copyright (C) 2011-2016 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -21,15 +21,15 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/keys-3.11
 library-dirs: /usr/lib/ghc-7.10.3/site-local/keys-3.11
 data-dir: /usr/share/arm-linux-ghc-7.10.3/keys-3.11
-hs-libraries: HSkeys-3.11-FT0yMgPq2OK0SRzfYlHeEH
+hs-libraries: HSkeys-3.11-H6H2ELFfMMo4X0tqBHPkuO
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     comonad-5-e98e7adc8875accf64a86529d9aeae51
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    free-4.12.4-a5ffddbbf41dcb5e4b11e5d62a21f456
+    free-4.12.4-4d7b26d357ab46561e822913cd7a6493
     hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
-    semigroupoids-5.0.1-7b21d348d4b507a23638386627368bec
+    semigroupoids-5.0.1-53b0b3ecfca9d658a051ef7b22e11130
     semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
